@@ -17,8 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef _BALOO_FILEINDEXER_SERVICE_CONFIG_H_
-#define _BALOO_FILEINDEXER_SERVICE_CONFIG_H_
+#ifndef BALOO_FILEINDEXER_SERVICE_CONFIG_H_
+#define BALOO_FILEINDEXER_SERVICE_CONFIG_H_
 
 #include <QtCore/QObject>
 #include <QtCore/QList>
@@ -136,8 +136,13 @@ public:
      */
     bool folderInFolderList(const QString& path, QString& folder) const;
 
-Q_SIGNALS:
-    void configChanged();
+    /**
+     * Returns the internal version number of the Baloo database
+     */
+    int databaseVersion() const;
+    void setDatabaseVersion(int version);
+
+    bool indexingEnabled() const;
 
 public Q_SLOTS:
     /**
@@ -155,9 +160,6 @@ public Q_SLOTS:
      */
     void setInitialRun(bool isInitialRun);
 
-private Q_SLOTS:
-    void slotConfigDirty();
-
 private:
 
     void buildFolderCache();
